/*******************************************************
********************************************************
 
Autore : Mauro Laurenti
Versione : 1.0
Data : 18/11/2010
 
CopyRight 2010 all rights are reserved


********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) 
is intended for use solely and exclusively on Microchip PIC Microcontroller (registered mark).  
The software is owned by the Author, and is protected under applicable copyright laws. 
All rights are reserved. 
Any use in violation of the foregoing restrictions may subject the 
user to criminal sanctions under applicable laws (Italian or International ones), as well as to 
civil liability for the breach of the terms and conditions of this license. 
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the following 
software doesn't aim to commercial use or monetary earning of any kind.    

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES, 
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT, 
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR 
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************
PURPOSES
********************************************************

EasyUSB programming Framework
 
*******************************************************
*******************************************************/

#include <p18f4550.h>

#pragma config FOSC = HS 	
#pragma config WDT = OFF 	
#pragma config LVP = OFF 	
#pragma config PBADEN = OFF 

//OSC = HS  	Impostato per lavorare ad alta frequenza 
//WDT = OFF		Disabilito il watchdog timer
//LVP = OFF 	Disabilito programmazione LVP
//PBADEN = OFF  Disabilito gli ingressi analogici


void New_High_Priority_ISR_Code();
void New_Low_Priority_ISR_Code();

//*************************************************************
//            Definizione nuovi indirizzi
//*************************************************************

#define REMAPPED_RESET_VECTOR_ADDRESS            0x1000
#define REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS   0x1008
#define REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS    0x1018
     
//Vedi il file c018i.c
extern void _startup (void);        


//*************************************************************
//            Rimappatura Interrupt Service Routine
//*************************************************************

#pragma code REMAPPED_RESET_VECTOR = REMAPPED_RESET_VECTOR_ADDRESS
void _reset (void){
	_asm goto _startup _endasm
}

#pragma code REMAPPED_HIGH_INTERRUPT_VECTOR = REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS
void Remapped_High_ISR (void) {

	_asm goto New_High_Priority_ISR_Code _endasm
}

#pragma code REMAPPED_LOW_INTERRUPT_VECTOR = REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS
void Remapped_Low_ISR (void) {

	_asm goto New_Low_Priority_ISR_Code _endasm
}

//*************************************************************
//            Standard Interrupt Service Routine
//*************************************************************

#pragma code HIGH_INTERRUPT_VECTOR = 0x08
void High_ISR (void) {

	_asm goto REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS _endasm
}


#pragma code LOW_INTERRUPT_VECTOR = 0x18
void Low_ISR (void) {
	_asm goto REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS _endasm
}

#pragma code

	
//*************************************************************
//         Nuovi Interrupt Service Routines
//*************************************************************	

#pragma interrupt New_High_Priority_ISR_Code
void New_High_Priority_ISR_Code() {
	// Gestione Interrupt alta Priorita'
}


#pragma interruptlow New_Low_Priority_ISR_Code
void New_Low_Priority_ISR_Code(){
		// Gestione Interrupt bassa Priorita'	
}

//*************************************************************
//              Funzione main ()
//*************************************************************	
void main (void){
	
	// Imposto PORTA tutti ingressi 
	LATA = 0x00; 
 	TRISA = 0xFF;

	// Imposto PORTB tutti ingressi
 	LATB = 0x00; 
 	TRISB = 0xFF;

	// Imposto PORTC tutti ingressi
 	LATC = 0x00;    	 
 	TRISC = 0xFF;
 	
	// Imposto PORTD tutti ingressi e RD0-RD1 come uscite 
 	LATD = 0x00;  
 	TRISD = 0b11111100;

	// Imposto PORTE tutti ingressi
 	LATE = 0x00;
 	TRISE = 0xFF;

	// Ciclo infinito
	while (1) {

		// Controllo Switch S2
		if (PORTBbits.RB4 == 0) {
			LATDbits.LATD0 = 0x01;
		} else {
			LATDbits.LATD0 = 0x00;
		}

		// Controllo Switch S3
		if (PORTBbits.RB5 == 0) {
			LATDbits.LATD1 = 0x01;
		} else {
			LATDbits.LATD1 = 0x00;
		}			
 	} 	
}